let filters = {
    need: [
        "I am looking for on-the-job learning support and in role development options",
        "I need events, tools or resources that promote best practice sharing and collaboration",
        "I want to create interest and awareness around an upcoming event",
        "I want my team to be able to create learning on their own and at short notice",
        'I want to make the learning "stick" after a formal learning experience',
        "I want my team to have access to relevant domain content on demand",
        "I want to create a highly engaging and fun learning experience",
        "I want a learning solution which helps my team maintain the content",
        "I want to create multi-modal earning that impacts learners at the workplace",
        "I want to create structured facilitated/virtual sessions for skill building",
        "I want to create engaging full-spectrum learner experiences around domains/topics",
    ],
    category: ["Informal and Workplace Learning", "Formal Learning"],
    offering: [
        "eLearning/WBT",
        "Video",
        "iPDFs/iMaps",
        "Flipbook",
        "Games",
        "Simulations",
        "Virtual reality",
        "Augmented reality",
        "Webcast",
        "Micro Learning",
        "Blended Learning",
        "Case Studies",
        "3D Walkthroughs/Models",
    ],
};

let catalogue = [{
        title: "Code of Conduct 2022 Anglo English",
        thumbnail: "images/c1_thumb.jpg",
        mainimag: "images/c1_Inner_Banner.jpg",
        description: "An online training giving an overview of our Code of Conduct. The course details the various components within the Code and explains the useful resources it contains, giving the learner the opportunity to use them to work through some challenging scenarios.",
        solution: "The training on our Code of Conduct needed to be rolled out to learners globally and impart the same knowledge to apply in situations they face at work. This format (e-learning) of learning/training through online digital resources is self-paced, time efficient, learner-centric and easily accessible.",
        offering: 0,
        category: 1,
        need: 5,
        demourl: "video/AA_Hydrogen_DummyVid.mp4",
    },
    {
        title: "TravelFit",
        thumbnail: "images/c2_thumb.jpg",
        mainimag: "images/c2_Inner_Banner.jpg",
        description: "Travelling for work opens a world of experience and opportunity, but also poses some risks to employees' health and well-being. The TravelFit course helps all employees who travel, covering concepts such as travel safety, health and compliance.",
        solution: "The training on our TravelFit guidelines to be rolled out to learners globally and impart the same knowledge to apply when travelling anywhere for work. This format (e-learning) of learning/training through online digital resources is self-paced, time efficient, learner-centric and easily accessible.",
        offering: 0,
        category: 1,
        need: 4,
        demourl: "video/AA_Hydrogen_DummyVid.mp4",
    },
    {
        title: "Intermediary Risk Management",
        thumbnail: "images/c3_thumb.jpg",
        mainimag: "images/c3_Inner_Banner.jpg",
        description: "This content is about Intermediary Risk Management at Anglo American. A video training for Responsible Managers and Supply Chain on the Enhanced Intermediary Risk Management Process.",
        solution: "The training is for relevant stakeholders to understand which parties comprise intermediaries, and how to manage the potential risks of dealing with intermediaries. The video-based format makes learning more effective and engaging, reduces cognitive overload and maximizes retention.",
        offering: 1,
        category: 1,
        need: 4,
        demourl: "video/AA_Hydrogen_DummyVid.mp4",
    },
];

let selectedFilter = [];

$(document).ready(function() {
    // console.log( "ready!" );
    resetView();

    populateDD("need");
    populateDD("category");
    populateDD("offering");

    populateCatalogue();

    assignEvents();
});

function resetView() {
    $(".page-home").show();
    $(".page-item").hide();
    $(".page-video").hide();
	$(".home-btn").hide();
    $(".offering-help-popup").hide();
	$('.error').hide();
	
}

function assignEvents() {
    $(document).on("change", "select", function(e) {
        selectedFilter = [];
        $("#need-dd").val() != "" ? selectedFilter.push($("#need-dd").val()) : null;
        $("#category-dd").val() != "" ? selectedFilter.push($("#category-dd").val()) : null;
        $("#offering-dd").val() != "" ? selectedFilter.push($("#offering-dd").val()) : null;

        applyFilter();
    });

    $(document).on("keyup", "input", function(e) {
        applyFilter();
    });

    $("#btn-reset")
        .off()
        .on("click", function() {
			selectedFilter=[];
			//console.log(selectedFilter);
			
            $("#need-dd").val("");
            $("#category-dd").val("");
            $("#offering-dd").val("");
			
			$('.error').hide();

            $(".catalogue-item").show();

            $("#search-box").val("");
        });
		
	 $(".home-btn").off()
        .on("click", function() {
        $("#btn-reset").click();
		resetView();
        });

    $(".offering-help-btn")
        .off()
        .on("click", function() {
            $(".offering-help-popup").show();
        });

    $(".offering-help-popup .popup-close-btn")
        .off()
        .on("click", function() {
            $(".offering-help-popup").hide();
        });

    $(".catalogue-item")
        .off()
        .on("click", function() {
            populateItem($(this).attr("data-id"));
            $(".page-home").hide();
            $(".page-item").show();
            $(".page-video").hide();
			
			$(".home-btn").show();
        });

    $(".page-item  #access-course")
        .off()
        .on("click", function() {
            populateVideo($(this).attr("data-id"));
            $(".page-home").hide();
            $(".page-item").hide();
            $(".page-video").show();
        });
}

function applyFilter() {
	all_are_hidden = true;
	console.log(selectedFilter);
	
    $(".catalogue-item").each(function() {
        let $item = $(this);
        let _c = $item.attr("class");
        let _m = [];
        for(let f = 0; f < selectedFilter.length; f++) {
            if(_c.indexOf(selectedFilter[f]) == -1) {
                _m.push("0");
            } else {
                _m.push("1");
            }
        }

        if($("search-box").val() != "") {
            let $t = $item.find(".catalogue-title");
            //console.log($t);

            let _tt = $t.text().toLowerCase();
            let _st = $("#search-box").val().toLowerCase();

            if(_tt.indexOf(_st) == -1) {
                _m.push("0");
            } else {
                _m.push("1");
            }
        }
        //console.log(_m);
        if(_m.indexOf("0") !== -1) {
            $(this).hide();
        } else {
            $(this).show();
			all_are_hidden = false;
        }
    });
	
	if(all_are_hidden){
		$('.error').show();
	}else{
		$('.error').hide();
	}
}

function populateDD(ddId) {
    let $data = filters[ddId];
    let s = "";
    for(var i = 0; i < $data.length; i++) {
        s += '<option value="' + ddId + i + '">' + $data[i] + "</option>";
    }
    $("#" + ddId + "-dd").append(s);
}

function populateCatalogue() {
    let _html = "";
    for(let i = 0; i < catalogue.length; i++) {
        let $item = catalogue[i];
        _html +=
            "<div class='catalogue-item mr-4 mb-4 mb-lg-0 category" +
            $item.category +
            " offering" +
            $item.offering +
			" need" +
            $item.need +
            "' id='c" +
            (i + 1) +
            "' data-id='" +
            i +
            "' style='background-image:url(" +
            $item.thumbnail +
            ")'><div class='catalogue-title p-4'>" +
            $item.title +
            "</div></div>";
    }
    console.log(_html);
    $(".container.catalogue > .d-flex").html(_html);
}

function populateItem(_id) {
    console.log(_id);
    let $item = catalogue[_id];

	console.log($item.description);
    $(".item-title").text($item.title); //video and itempage both;

    $(".page-item .item-base-content .item-category").text(filters["category"][$item.category]);
    $(".page-item .item-base-content .item-offering").text(filters["offering"][$item.offering]);
	

    $(".page-item .item-base-content .base-img").attr("src", $item.mainimag);

    $(".page-item  .item-description").text($item.description);
    $(".page-item  .item-solution").text($item.solution);

    $(".page-item  #access-course").attr("data-id", _id);
}

function populateVideo(_id) {
    let $item = catalogue[_id];
	console.log($item);
    var video = $(".item-video")[0];
    video.src = $item['demourl'];
    video.load();
    //video.play();
}